# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ReinforcementFineTuningStepGetParams"]


class ReinforcementFineTuningStepGetParams(TypedDict, total=False):
    account_id: str

    read_mask: Annotated[str, PropertyInfo(alias="readMask")]
    """The fields to be returned in the response.

    If empty or "\\**", all fields will be returned.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import evaluator_get_params, evaluator_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.evaluator_get_response import EvaluatorGetResponse
from ..types.evaluator_list_response import EvaluatorListResponse

__all__ = ["EvaluatorsResource", "AsyncEvaluatorsResource"]


class EvaluatorsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EvaluatorsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return EvaluatorsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EvaluatorsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return EvaluatorsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorListResponse:
        """Args:
          read_mask: The fields to be returned in the response.

        If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get(
            f"/v1/accounts/{account_id}/evaluators"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    evaluator_list_params.EvaluatorListParams,
                ),
            ),
            cast_to=EvaluatorListResponse,
        )

    def delete(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._delete(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def get(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetResponse:
        """Args:
          read_mask: The fields to be returned in the response.

        If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._get(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"read_mask": read_mask}, evaluator_get_params.EvaluatorGetParams),
            ),
            cast_to=EvaluatorGetResponse,
        )


class AsyncEvaluatorsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEvaluatorsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncEvaluatorsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEvaluatorsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return AsyncEvaluatorsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorListResponse:
        """Args:
          read_mask: The fields to be returned in the response.

        If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._get(
            f"/v1/accounts/{account_id}/evaluators"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    evaluator_list_params.EvaluatorListParams,
                ),
            ),
            cast_to=EvaluatorListResponse,
        )

    async def delete(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._delete(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def get(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetResponse:
        """Args:
          read_mask: The fields to be returned in the response.

        If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._get(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"read_mask": read_mask}, evaluator_get_params.EvaluatorGetParams),
            ),
            cast_to=EvaluatorGetResponse,
        )


class EvaluatorsResourceWithRawResponse:
    def __init__(self, evaluators: EvaluatorsResource) -> None:
        self._evaluators = evaluators

        self.list = to_raw_response_wrapper(
            evaluators.list,
        )
        self.delete = to_raw_response_wrapper(
            evaluators.delete,
        )
        self.get = to_raw_response_wrapper(
            evaluators.get,
        )


class AsyncEvaluatorsResourceWithRawResponse:
    def __init__(self, evaluators: AsyncEvaluatorsResource) -> None:
        self._evaluators = evaluators

        self.list = async_to_raw_response_wrapper(
            evaluators.list,
        )
        self.delete = async_to_raw_response_wrapper(
            evaluators.delete,
        )
        self.get = async_to_raw_response_wrapper(
            evaluators.get,
        )


class EvaluatorsResourceWithStreamingResponse:
    def __init__(self, evaluators: EvaluatorsResource) -> None:
        self._evaluators = evaluators

        self.list = to_streamed_response_wrapper(
            evaluators.list,
        )
        self.delete = to_streamed_response_wrapper(
            evaluators.delete,
        )
        self.get = to_streamed_response_wrapper(
            evaluators.get,
        )


class AsyncEvaluatorsResourceWithStreamingResponse:
    def __init__(self, evaluators: AsyncEvaluatorsResource) -> None:
        self._evaluators = evaluators

        self.list = async_to_streamed_response_wrapper(
            evaluators.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            evaluators.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            evaluators.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import deployment_shape_version_get_params, deployment_shape_version_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.deployment_shape_version_get_response import DeploymentShapeVersionGetResponse
from ..types.deployment_shape_version_list_response import DeploymentShapeVersionListResponse

__all__ = ["DeploymentShapeVersionsResource", "AsyncDeploymentShapeVersionsResource"]


class DeploymentShapeVersionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DeploymentShapeVersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return DeploymentShapeVersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DeploymentShapeVersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return DeploymentShapeVersionsResourceWithStreamingResponse(self)

    def list(
        self,
        deployment_shape_id: str,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentShapeVersionListResponse:
        """
        List Deployment Shapes Versions

        Args:
          filter: Only deployment shape versions satisfying the provided filter (if specified)
              will be returned. See https://google.aip.dev/160 for the filter grammar.

          order_by: A comma-separated list of fields to order by. e.g. "foo,bar" The default sort
              order is ascending. To specify a descending order for a field, append a " desc"
              suffix. e.g. "foo desc,bar" Subfields are specified with a "." character. e.g.
              "foo.bar" If not specified, the default order is by "create_time".

          page_size: The maximum number of deployment shape versions to return. The maximum page_size
              is 200, values above 200 will be coerced to 200. If unspecified, the default
              is 50.

          page_token: A page token, received from a previous ListDeploymentShapeVersions call. Provide
              this to retrieve the subsequent page. When paginating, all other parameters
              provided to ListDeploymentShapeVersions must match the call that provided the
              page token.

          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not deployment_shape_id:
            raise ValueError(
                f"Expected a non-empty value for `deployment_shape_id` but received {deployment_shape_id!r}"
            )
        return self._get(
            f"/v1/accounts/{account_id}/deploymentShapes/{deployment_shape_id}/versions"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/deploymentShapes/{deployment_shape_id}/versions",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    deployment_shape_version_list_params.DeploymentShapeVersionListParams,
                ),
            ),
            cast_to=DeploymentShapeVersionListResponse,
        )

    def get(
        self,
        version_id: str,
        *,
        account_id: str | None = None,
        deployment_shape_id: str,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentShapeVersionGetResponse:
        """
        Get Deployment Shape Version

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not deployment_shape_id:
            raise ValueError(
                f"Expected a non-empty value for `deployment_shape_id` but received {deployment_shape_id!r}"
            )
        if not version_id:
            raise ValueError(f"Expected a non-empty value for `version_id` but received {version_id!r}")
        return self._get(
            f"/v1/accounts/{account_id}/deploymentShapes/{deployment_shape_id}/versions/{version_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/deploymentShapes/{deployment_shape_id}/versions/{version_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"read_mask": read_mask}, deployment_shape_version_get_params.DeploymentShapeVersionGetParams
                ),
            ),
            cast_to=DeploymentShapeVersionGetResponse,
        )


class AsyncDeploymentShapeVersionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDeploymentShapeVersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncDeploymentShapeVersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDeploymentShapeVersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return AsyncDeploymentShapeVersionsResourceWithStreamingResponse(self)

    async def list(
        self,
        deployment_shape_id: str,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentShapeVersionListResponse:
        """
        List Deployment Shapes Versions

        Args:
          filter: Only deployment shape versions satisfying the provided filter (if specified)
              will be returned. See https://google.aip.dev/160 for the filter grammar.

          order_by: A comma-separated list of fields to order by. e.g. "foo,bar" The default sort
              order is ascending. To specify a descending order for a field, append a " desc"
              suffix. e.g. "foo desc,bar" Subfields are specified with a "." character. e.g.
              "foo.bar" If not specified, the default order is by "create_time".

          page_size: The maximum number of deployment shape versions to return. The maximum page_size
              is 200, values above 200 will be coerced to 200. If unspecified, the default
              is 50.

          page_token: A page token, received from a previous ListDeploymentShapeVersions call. Provide
              this to retrieve the subsequent page. When paginating, all other parameters
              provided to ListDeploymentShapeVersions must match the call that provided the
              page token.

          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not deployment_shape_id:
            raise ValueError(
                f"Expected a non-empty value for `deployment_shape_id` but received {deployment_shape_id!r}"
            )
        return await self._get(
            f"/v1/accounts/{account_id}/deploymentShapes/{deployment_shape_id}/versions"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/deploymentShapes/{deployment_shape_id}/versions",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    deployment_shape_version_list_params.DeploymentShapeVersionListParams,
                ),
            ),
            cast_to=DeploymentShapeVersionListResponse,
        )

    async def get(
        self,
        version_id: str,
        *,
        account_id: str | None = None,
        deployment_shape_id: str,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DeploymentShapeVersionGetResponse:
        """
        Get Deployment Shape Version

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not deployment_shape_id:
            raise ValueError(
                f"Expected a non-empty value for `deployment_shape_id` but received {deployment_shape_id!r}"
            )
        if not version_id:
            raise ValueError(f"Expected a non-empty value for `version_id` but received {version_id!r}")
        return await self._get(
            f"/v1/accounts/{account_id}/deploymentShapes/{deployment_shape_id}/versions/{version_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/deploymentShapes/{deployment_shape_id}/versions/{version_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"read_mask": read_mask}, deployment_shape_version_get_params.DeploymentShapeVersionGetParams
                ),
            ),
            cast_to=DeploymentShapeVersionGetResponse,
        )


class DeploymentShapeVersionsResourceWithRawResponse:
    def __init__(self, deployment_shape_versions: DeploymentShapeVersionsResource) -> None:
        self._deployment_shape_versions = deployment_shape_versions

        self.list = to_raw_response_wrapper(
            deployment_shape_versions.list,
        )
        self.get = to_raw_response_wrapper(
            deployment_shape_versions.get,
        )


class AsyncDeploymentShapeVersionsResourceWithRawResponse:
    def __init__(self, deployment_shape_versions: AsyncDeploymentShapeVersionsResource) -> None:
        self._deployment_shape_versions = deployment_shape_versions

        self.list = async_to_raw_response_wrapper(
            deployment_shape_versions.list,
        )
        self.get = async_to_raw_response_wrapper(
            deployment_shape_versions.get,
        )


class DeploymentShapeVersionsResourceWithStreamingResponse:
    def __init__(self, deployment_shape_versions: DeploymentShapeVersionsResource) -> None:
        self._deployment_shape_versions = deployment_shape_versions

        self.list = to_streamed_response_wrapper(
            deployment_shape_versions.list,
        )
        self.get = to_streamed_response_wrapper(
            deployment_shape_versions.get,
        )


class AsyncDeploymentShapeVersionsResourceWithStreamingResponse:
    def __init__(self, deployment_shape_versions: AsyncDeploymentShapeVersionsResource) -> None:
        self._deployment_shape_versions = deployment_shape_versions

        self.list = async_to_streamed_response_wrapper(
            deployment_shape_versions.list,
        )
        self.get = async_to_streamed_response_wrapper(
            deployment_shape_versions.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["DeploymentDeleteParams"]


class DeploymentDeleteParams(TypedDict, total=False):
    account_id: str

    hard: bool
    """If true, this will perform a hard deletion."""

    ignore_checks: Annotated[bool, PropertyInfo(alias="ignoreChecks")]
    """
    If true, this will ignore checks and force the deletion of a deployment that is
    currently deployed and is in use.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .chat import (
    ChatResource,
    AsyncChatResource,
    ChatResourceWithRawResponse,
    AsyncChatResourceWithRawResponse,
    ChatResourceWithStreamingResponse,
    AsyncChatResourceWithStreamingResponse,
)
from .lora import (
    LoraResource,
    AsyncLoraResource,
    LoraResourceWithRawResponse,
    AsyncLoraResourceWithRawResponse,
    LoraResourceWithStreamingResponse,
    AsyncLoraResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .models import (
    ModelsResource,
    AsyncModelsResource,
    ModelsResourceWithRawResponse,
    AsyncModelsResourceWithRawResponse,
    ModelsResourceWithStreamingResponse,
    AsyncModelsResourceWithStreamingResponse,
)
from .secrets import (
    SecretsResource,
    AsyncSecretsResource,
    SecretsResourceWithRawResponse,
    AsyncSecretsResourceWithRawResponse,
    SecretsResourceWithStreamingResponse,
    AsyncSecretsResourceWithStreamingResponse,
)
from .accounts import (
    AccountsResource,
    AsyncAccountsResource,
    AccountsResourceWithRawResponse,
    AsyncAccountsResourceWithRawResponse,
    AccountsResourceWithStreamingResponse,
    AsyncAccountsResourceWithStreamingResponse,
)
from .api_keys import (
    APIKeysResource,
    AsyncAPIKeysResource,
    APIKeysResourceWithRawResponse,
    AsyncAPIKeysResourceWithRawResponse,
    APIKeysResourceWithStreamingResponse,
    AsyncAPIKeysResourceWithStreamingResponse,
)
from .datasets import (
    DatasetsResource,
    AsyncDatasetsResource,
    DatasetsResourceWithRawResponse,
    AsyncDatasetsResourceWithRawResponse,
    DatasetsResourceWithStreamingResponse,
    AsyncDatasetsResourceWithStreamingResponse,
)
from .dpo_jobs import (
    DpoJobsResource,
    AsyncDpoJobsResource,
    DpoJobsResourceWithRawResponse,
    AsyncDpoJobsResourceWithRawResponse,
    DpoJobsResourceWithStreamingResponse,
    AsyncDpoJobsResourceWithStreamingResponse,
)
from .evaluators import (
    EvaluatorsResource,
    AsyncEvaluatorsResource,
    EvaluatorsResourceWithRawResponse,
    AsyncEvaluatorsResourceWithRawResponse,
    EvaluatorsResourceWithStreamingResponse,
    AsyncEvaluatorsResourceWithStreamingResponse,
)
from .completions import (
    CompletionsResource,
    AsyncCompletionsResource,
    CompletionsResourceWithRawResponse,
    AsyncCompletionsResourceWithRawResponse,
    CompletionsResourceWithStreamingResponse,
    AsyncCompletionsResourceWithStreamingResponse,
)
from .deployments import (
    DeploymentsResource,
    AsyncDeploymentsResource,
    DeploymentsResourceWithRawResponse,
    AsyncDeploymentsResourceWithRawResponse,
    DeploymentsResourceWithStreamingResponse,
    AsyncDeploymentsResourceWithStreamingResponse,
)
from .evaluation_jobs import (
    EvaluationJobsResource,
    AsyncEvaluationJobsResource,
    EvaluationJobsResourceWithRawResponse,
    AsyncEvaluationJobsResourceWithRawResponse,
    EvaluationJobsResourceWithStreamingResponse,
    AsyncEvaluationJobsResourceWithStreamingResponse,
)
from .batch_inference_jobs import (
    BatchInferenceJobsResource,
    AsyncBatchInferenceJobsResource,
    BatchInferenceJobsResourceWithRawResponse,
    AsyncBatchInferenceJobsResourceWithRawResponse,
    BatchInferenceJobsResourceWithStreamingResponse,
    AsyncBatchInferenceJobsResourceWithStreamingResponse,
)
from .deployment_shape_versions import (
    DeploymentShapeVersionsResource,
    AsyncDeploymentShapeVersionsResource,
    DeploymentShapeVersionsResourceWithRawResponse,
    AsyncDeploymentShapeVersionsResourceWithRawResponse,
    DeploymentShapeVersionsResourceWithStreamingResponse,
    AsyncDeploymentShapeVersionsResourceWithStreamingResponse,
)
from .supervised_fine_tuning_jobs import (
    SupervisedFineTuningJobsResource,
    AsyncSupervisedFineTuningJobsResource,
    SupervisedFineTuningJobsResourceWithRawResponse,
    AsyncSupervisedFineTuningJobsResourceWithRawResponse,
    SupervisedFineTuningJobsResourceWithStreamingResponse,
    AsyncSupervisedFineTuningJobsResourceWithStreamingResponse,
)
from .reinforcement_fine_tuning_jobs import (
    ReinforcementFineTuningJobsResource,
    AsyncReinforcementFineTuningJobsResource,
    ReinforcementFineTuningJobsResourceWithRawResponse,
    AsyncReinforcementFineTuningJobsResourceWithRawResponse,
    ReinforcementFineTuningJobsResourceWithStreamingResponse,
    AsyncReinforcementFineTuningJobsResourceWithStreamingResponse,
)
from .reinforcement_fine_tuning_steps import (
    ReinforcementFineTuningStepsResource,
    AsyncReinforcementFineTuningStepsResource,
    ReinforcementFineTuningStepsResourceWithRawResponse,
    AsyncReinforcementFineTuningStepsResourceWithRawResponse,
    ReinforcementFineTuningStepsResourceWithStreamingResponse,
    AsyncReinforcementFineTuningStepsResourceWithStreamingResponse,
)

__all__ = [
    "ChatResource",
    "AsyncChatResource",
    "ChatResourceWithRawResponse",
    "AsyncChatResourceWithRawResponse",
    "ChatResourceWithStreamingResponse",
    "AsyncChatResourceWithStreamingResponse",
    "CompletionsResource",
    "AsyncCompletionsResource",
    "CompletionsResourceWithRawResponse",
    "AsyncCompletionsResourceWithRawResponse",
    "CompletionsResourceWithStreamingResponse",
    "AsyncCompletionsResourceWithStreamingResponse",
    "BatchInferenceJobsResource",
    "AsyncBatchInferenceJobsResource",
    "BatchInferenceJobsResourceWithRawResponse",
    "AsyncBatchInferenceJobsResourceWithRawResponse",
    "BatchInferenceJobsResourceWithStreamingResponse",
    "AsyncBatchInferenceJobsResourceWithStreamingResponse",
    "DeploymentsResource",
    "AsyncDeploymentsResource",
    "DeploymentsResourceWithRawResponse",
    "AsyncDeploymentsResourceWithRawResponse",
    "DeploymentsResourceWithStreamingResponse",
    "AsyncDeploymentsResourceWithStreamingResponse",
    "ModelsResource",
    "AsyncModelsResource",
    "ModelsResourceWithRawResponse",
    "AsyncModelsResourceWithRawResponse",
    "ModelsResourceWithStreamingResponse",
    "AsyncModelsResourceWithStreamingResponse",
    "LoraResource",
    "AsyncLoraResource",
    "LoraResourceWithRawResponse",
    "AsyncLoraResourceWithRawResponse",
    "LoraResourceWithStreamingResponse",
    "AsyncLoraResourceWithStreamingResponse",
    "DeploymentShapeVersionsResource",
    "AsyncDeploymentShapeVersionsResource",
    "DeploymentShapeVersionsResourceWithRawResponse",
    "AsyncDeploymentShapeVersionsResourceWithRawResponse",
    "DeploymentShapeVersionsResourceWithStreamingResponse",
    "AsyncDeploymentShapeVersionsResourceWithStreamingResponse",
    "DatasetsResource",
    "AsyncDatasetsResource",
    "DatasetsResourceWithRawResponse",
    "AsyncDatasetsResourceWithRawResponse",
    "DatasetsResourceWithStreamingResponse",
    "AsyncDatasetsResourceWithStreamingResponse",
    "SupervisedFineTuningJobsResource",
    "AsyncSupervisedFineTuningJobsResource",
    "SupervisedFineTuningJobsResourceWithRawResponse",
    "AsyncSupervisedFineTuningJobsResourceWithRawResponse",
    "SupervisedFineTuningJobsResourceWithStreamingResponse",
    "AsyncSupervisedFineTuningJobsResourceWithStreamingResponse",
    "ReinforcementFineTuningJobsResource",
    "AsyncReinforcementFineTuningJobsResource",
    "ReinforcementFineTuningJobsResourceWithRawResponse",
    "AsyncReinforcementFineTuningJobsResourceWithRawResponse",
    "ReinforcementFineTuningJobsResourceWithStreamingResponse",
    "AsyncReinforcementFineTuningJobsResourceWithStreamingResponse",
    "ReinforcementFineTuningStepsResource",
    "AsyncReinforcementFineTuningStepsResource",
    "ReinforcementFineTuningStepsResourceWithRawResponse",
    "AsyncReinforcementFineTuningStepsResourceWithRawResponse",
    "ReinforcementFineTuningStepsResourceWithStreamingResponse",
    "AsyncReinforcementFineTuningStepsResourceWithStreamingResponse",
    "DpoJobsResource",
    "AsyncDpoJobsResource",
    "DpoJobsResourceWithRawResponse",
    "AsyncDpoJobsResourceWithRawResponse",
    "DpoJobsResourceWithStreamingResponse",
    "AsyncDpoJobsResourceWithStreamingResponse",
    "EvaluationJobsResource",
    "AsyncEvaluationJobsResource",
    "EvaluationJobsResourceWithRawResponse",
    "AsyncEvaluationJobsResourceWithRawResponse",
    "EvaluationJobsResourceWithStreamingResponse",
    "AsyncEvaluationJobsResourceWithStreamingResponse",
    "EvaluatorsResource",
    "AsyncEvaluatorsResource",
    "EvaluatorsResourceWithRawResponse",
    "AsyncEvaluatorsResourceWithRawResponse",
    "EvaluatorsResourceWithStreamingResponse",
    "AsyncEvaluatorsResourceWithStreamingResponse",
    "AccountsResource",
    "AsyncAccountsResource",
    "AccountsResourceWithRawResponse",
    "AsyncAccountsResourceWithRawResponse",
    "AccountsResourceWithStreamingResponse",
    "AsyncAccountsResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
    "APIKeysResource",
    "AsyncAPIKeysResource",
    "APIKeysResourceWithRawResponse",
    "AsyncAPIKeysResourceWithRawResponse",
    "APIKeysResourceWithStreamingResponse",
    "AsyncAPIKeysResourceWithStreamingResponse",
    "SecretsResource",
    "AsyncSecretsResource",
    "SecretsResourceWithRawResponse",
    "AsyncSecretsResourceWithRawResponse",
    "SecretsResourceWithStreamingResponse",
    "AsyncSecretsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.status import Status

__all__ = ["EvaluationJobListResponse", "EvaluationJob"]


class EvaluationJob(BaseModel):
    evaluator: str
    """The fully-qualified resource name of the Evaluation used by this job.

    Format: accounts/{account_id}/evaluators/{evaluator_id}
    """

    input_dataset: str = FieldInfo(alias="inputDataset")
    """The fully-qualified resource name of the input Dataset used by this job.

    Format: accounts/{account_id}/datasets/{dataset_id}
    """

    output_dataset: str = FieldInfo(alias="outputDataset")
    """The fully-qualified resource name of the output Dataset created by this job.

    Format: accounts/{account_id}/datasets/{output_dataset_id}
    """

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)

    create_time: Optional[datetime] = FieldInfo(alias="createTime", default=None)

    display_name: Optional[str] = FieldInfo(alias="displayName", default=None)

    metrics: Optional[Dict[str, float]] = None

    name: Optional[str] = None

    output_stats: Optional[str] = FieldInfo(alias="outputStats", default=None)
    """The output dataset's aggregated stats for the evaluation job."""

    state: Optional[
        Literal[
            "JOB_STATE_UNSPECIFIED",
            "JOB_STATE_CREATING",
            "JOB_STATE_RUNNING",
            "JOB_STATE_COMPLETED",
            "JOB_STATE_FAILED",
            "JOB_STATE_CANCELLED",
            "JOB_STATE_DELETING",
            "JOB_STATE_WRITING_RESULTS",
            "JOB_STATE_VALIDATING",
            "JOB_STATE_DELETING_CLEANING_UP",
            "JOB_STATE_PENDING",
            "JOB_STATE_EXPIRED",
            "JOB_STATE_RE_QUEUEING",
            "JOB_STATE_CREATING_INPUT_DATASET",
            "JOB_STATE_IDLE",
            "JOB_STATE_CANCELLING",
            "JOB_STATE_EARLY_STOPPED",
            "JOB_STATE_PAUSED",
        ]
    ] = None
    """JobState represents the state an asynchronous job can be in.

    - JOB_STATE_PAUSED: Job is paused, typically due to account suspension or manual
      intervention.
    """

    status: Optional[Status] = None

    update_time: Optional[datetime] = FieldInfo(alias="updateTime", default=None)
    """The update time for the evaluation job."""


class EvaluationJobListResponse(BaseModel):
    evaluation_jobs: Optional[List[EvaluationJob]] = FieldInfo(alias="evaluationJobs", default=None)

    next_page_token: Optional[str] = FieldInfo(alias="nextPageToken", default=None)

    total_size: Optional[int] = FieldInfo(alias="totalSize", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    reinforcement_fine_tuning_job_get_params,
    reinforcement_fine_tuning_job_list_params,
    reinforcement_fine_tuning_job_cancel_params,
    reinforcement_fine_tuning_job_create_params,
    reinforcement_fine_tuning_job_resume_params,
)
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.shared_params.wandb_config import WandbConfig
from ..types.reinforcement_fine_tuning_job import ReinforcementFineTuningJob
from ..types.shared_params.training_config import TrainingConfig
from ..types.shared_params.inference_parameters import InferenceParameters
from ..types.reinforcement_fine_tuning_job_list_response import ReinforcementFineTuningJobListResponse

__all__ = ["ReinforcementFineTuningJobsResource", "AsyncReinforcementFineTuningJobsResource"]


class ReinforcementFineTuningJobsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ReinforcementFineTuningJobsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return ReinforcementFineTuningJobsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ReinforcementFineTuningJobsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return ReinforcementFineTuningJobsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str | None = None,
        dataset: str,
        evaluator: str,
        reinforcement_fine_tuning_job_id: str | Omit = omit,
        chunk_size: int | Omit = omit,
        display_name: str | Omit = omit,
        eval_auto_carveout: bool | Omit = omit,
        evaluation_dataset: str | Omit = omit,
        inference_parameters: InferenceParameters | Omit = omit,
        mcp_server: str | Omit = omit,
        node_count: int | Omit = omit,
        training_config: TrainingConfig | Omit = omit,
        wandb_config: WandbConfig | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReinforcementFineTuningJob:
        """
        Create Reinforcement Fine-tuning Job

        Args:
          dataset: The name of the dataset used for training.

          evaluator: The evaluator resource name to use for RLOR fine-tuning job.

          reinforcement_fine_tuning_job_id: ID of the reinforcement fine-tuning job, a random UUID will be generated if not
              specified.

          chunk_size: Data chunking for rollout, default size 200, enabled when dataset > 300. Valid
              range is 1-10,000.

          eval_auto_carveout: Whether to auto-carve the dataset for eval.

          evaluation_dataset: The name of a separate dataset to use for evaluation.

          inference_parameters: BIJ parameters.

          node_count: The number of nodes to use for the fine-tuning job. If not specified, the
              default is 1.

          training_config: Common training configurations.

          wandb_config: The Weights & Biases team/user account for logging training progress.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs",
            body=maybe_transform(
                {
                    "dataset": dataset,
                    "evaluator": evaluator,
                    "chunk_size": chunk_size,
                    "display_name": display_name,
                    "eval_auto_carveout": eval_auto_carveout,
                    "evaluation_dataset": evaluation_dataset,
                    "inference_parameters": inference_parameters,
                    "mcp_server": mcp_server,
                    "node_count": node_count,
                    "training_config": training_config,
                    "wandb_config": wandb_config,
                },
                reinforcement_fine_tuning_job_create_params.ReinforcementFineTuningJobCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"reinforcement_fine_tuning_job_id": reinforcement_fine_tuning_job_id},
                    reinforcement_fine_tuning_job_create_params.ReinforcementFineTuningJobCreateParams,
                ),
            ),
            cast_to=ReinforcementFineTuningJob,
        )

    def list(
        self,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReinforcementFineTuningJobListResponse:
        """
        List Reinforcement Fine-tuning Jobs

        Args:
          filter: Filter criteria for the returned jobs. See https://google.aip.dev/160 for the
              filter syntax specification.

          order_by: A comma-separated list of fields to order by. e.g. "foo,bar" The default sort
              order is ascending. To specify a descending order for a field, append a " desc"
              suffix. e.g. "foo desc,bar" Subfields are specified with a "." character. e.g.
              "foo.bar" If not specified, the default order is by "name".

          page_size: The maximum number of fine-tuning jobs to return. The maximum page_size is 200,
              values above 200 will be coerced to 200. If unspecified, the default is 50.

          page_token: A page token, received from a previous ListReinforcementLearningFineTuningJobs
              call. Provide this to retrieve the subsequent page. When paginating, all other
              parameters provided to ListReinforcementLearningFineTuningJobs must match the
              call that provided the page token.

          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    reinforcement_fine_tuning_job_list_params.ReinforcementFineTuningJobListParams,
                ),
            ),
            cast_to=ReinforcementFineTuningJobListResponse,
        )

    def delete(
        self,
        reinforcement_fine_tuning_job_id: str,
        *,
        account_id: str | None = None,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Delete Reinforcement Fine-tuning Job

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not reinforcement_fine_tuning_job_id:
            raise ValueError(
                f"Expected a non-empty value for `reinforcement_fine_tuning_job_id` but received {reinforcement_fine_tuning_job_id!r}"
            )
        return self._delete(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def cancel(
        self,
        reinforcement_fine_tuning_job_id: str,
        *,
        account_id: str | None = None,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Cancel Reinforcement Fine-tuning Job

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not reinforcement_fine_tuning_job_id:
            raise ValueError(
                f"Expected a non-empty value for `reinforcement_fine_tuning_job_id` but received {reinforcement_fine_tuning_job_id!r}"
            )
        return self._post(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}:cancel"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}:cancel",
            body=maybe_transform(
                body, reinforcement_fine_tuning_job_cancel_params.ReinforcementFineTuningJobCancelParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def get(
        self,
        reinforcement_fine_tuning_job_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReinforcementFineTuningJob:
        """
        Get Reinforcement Fine-tuning Job

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not reinforcement_fine_tuning_job_id:
            raise ValueError(
                f"Expected a non-empty value for `reinforcement_fine_tuning_job_id` but received {reinforcement_fine_tuning_job_id!r}"
            )
        return self._get(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"read_mask": read_mask},
                    reinforcement_fine_tuning_job_get_params.ReinforcementFineTuningJobGetParams,
                ),
            ),
            cast_to=ReinforcementFineTuningJob,
        )

    def resume(
        self,
        reinforcement_fine_tuning_job_id: str,
        *,
        account_id: str | None = None,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReinforcementFineTuningJob:
        """
        Resume Reinforcement Fine-tuning Job

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not reinforcement_fine_tuning_job_id:
            raise ValueError(
                f"Expected a non-empty value for `reinforcement_fine_tuning_job_id` but received {reinforcement_fine_tuning_job_id!r}"
            )
        return self._post(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}:resume"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}:resume",
            body=maybe_transform(
                body, reinforcement_fine_tuning_job_resume_params.ReinforcementFineTuningJobResumeParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ReinforcementFineTuningJob,
        )


class AsyncReinforcementFineTuningJobsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncReinforcementFineTuningJobsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncReinforcementFineTuningJobsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncReinforcementFineTuningJobsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return AsyncReinforcementFineTuningJobsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str | None = None,
        dataset: str,
        evaluator: str,
        reinforcement_fine_tuning_job_id: str | Omit = omit,
        chunk_size: int | Omit = omit,
        display_name: str | Omit = omit,
        eval_auto_carveout: bool | Omit = omit,
        evaluation_dataset: str | Omit = omit,
        inference_parameters: InferenceParameters | Omit = omit,
        mcp_server: str | Omit = omit,
        node_count: int | Omit = omit,
        training_config: TrainingConfig | Omit = omit,
        wandb_config: WandbConfig | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReinforcementFineTuningJob:
        """
        Create Reinforcement Fine-tuning Job

        Args:
          dataset: The name of the dataset used for training.

          evaluator: The evaluator resource name to use for RLOR fine-tuning job.

          reinforcement_fine_tuning_job_id: ID of the reinforcement fine-tuning job, a random UUID will be generated if not
              specified.

          chunk_size: Data chunking for rollout, default size 200, enabled when dataset > 300. Valid
              range is 1-10,000.

          eval_auto_carveout: Whether to auto-carve the dataset for eval.

          evaluation_dataset: The name of a separate dataset to use for evaluation.

          inference_parameters: BIJ parameters.

          node_count: The number of nodes to use for the fine-tuning job. If not specified, the
              default is 1.

          training_config: Common training configurations.

          wandb_config: The Weights & Biases team/user account for logging training progress.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs",
            body=await async_maybe_transform(
                {
                    "dataset": dataset,
                    "evaluator": evaluator,
                    "chunk_size": chunk_size,
                    "display_name": display_name,
                    "eval_auto_carveout": eval_auto_carveout,
                    "evaluation_dataset": evaluation_dataset,
                    "inference_parameters": inference_parameters,
                    "mcp_server": mcp_server,
                    "node_count": node_count,
                    "training_config": training_config,
                    "wandb_config": wandb_config,
                },
                reinforcement_fine_tuning_job_create_params.ReinforcementFineTuningJobCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"reinforcement_fine_tuning_job_id": reinforcement_fine_tuning_job_id},
                    reinforcement_fine_tuning_job_create_params.ReinforcementFineTuningJobCreateParams,
                ),
            ),
            cast_to=ReinforcementFineTuningJob,
        )

    async def list(
        self,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReinforcementFineTuningJobListResponse:
        """
        List Reinforcement Fine-tuning Jobs

        Args:
          filter: Filter criteria for the returned jobs. See https://google.aip.dev/160 for the
              filter syntax specification.

          order_by: A comma-separated list of fields to order by. e.g. "foo,bar" The default sort
              order is ascending. To specify a descending order for a field, append a " desc"
              suffix. e.g. "foo desc,bar" Subfields are specified with a "." character. e.g.
              "foo.bar" If not specified, the default order is by "name".

          page_size: The maximum number of fine-tuning jobs to return. The maximum page_size is 200,
              values above 200 will be coerced to 200. If unspecified, the default is 50.

          page_token: A page token, received from a previous ListReinforcementLearningFineTuningJobs
              call. Provide this to retrieve the subsequent page. When paginating, all other
              parameters provided to ListReinforcementLearningFineTuningJobs must match the
              call that provided the page token.

          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._get(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    reinforcement_fine_tuning_job_list_params.ReinforcementFineTuningJobListParams,
                ),
            ),
            cast_to=ReinforcementFineTuningJobListResponse,
        )

    async def delete(
        self,
        reinforcement_fine_tuning_job_id: str,
        *,
        account_id: str | None = None,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Delete Reinforcement Fine-tuning Job

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not reinforcement_fine_tuning_job_id:
            raise ValueError(
                f"Expected a non-empty value for `reinforcement_fine_tuning_job_id` but received {reinforcement_fine_tuning_job_id!r}"
            )
        return await self._delete(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def cancel(
        self,
        reinforcement_fine_tuning_job_id: str,
        *,
        account_id: str | None = None,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Cancel Reinforcement Fine-tuning Job

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not reinforcement_fine_tuning_job_id:
            raise ValueError(
                f"Expected a non-empty value for `reinforcement_fine_tuning_job_id` but received {reinforcement_fine_tuning_job_id!r}"
            )
        return await self._post(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}:cancel"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}:cancel",
            body=await async_maybe_transform(
                body, reinforcement_fine_tuning_job_cancel_params.ReinforcementFineTuningJobCancelParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def get(
        self,
        reinforcement_fine_tuning_job_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReinforcementFineTuningJob:
        """
        Get Reinforcement Fine-tuning Job

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not reinforcement_fine_tuning_job_id:
            raise ValueError(
                f"Expected a non-empty value for `reinforcement_fine_tuning_job_id` but received {reinforcement_fine_tuning_job_id!r}"
            )
        return await self._get(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"read_mask": read_mask},
                    reinforcement_fine_tuning_job_get_params.ReinforcementFineTuningJobGetParams,
                ),
            ),
            cast_to=ReinforcementFineTuningJob,
        )

    async def resume(
        self,
        reinforcement_fine_tuning_job_id: str,
        *,
        account_id: str | None = None,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ReinforcementFineTuningJob:
        """
        Resume Reinforcement Fine-tuning Job

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not reinforcement_fine_tuning_job_id:
            raise ValueError(
                f"Expected a non-empty value for `reinforcement_fine_tuning_job_id` but received {reinforcement_fine_tuning_job_id!r}"
            )
        return await self._post(
            f"/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}:resume"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/reinforcementFineTuningJobs/{reinforcement_fine_tuning_job_id}:resume",
            body=await async_maybe_transform(
                body, reinforcement_fine_tuning_job_resume_params.ReinforcementFineTuningJobResumeParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ReinforcementFineTuningJob,
        )


class ReinforcementFineTuningJobsResourceWithRawResponse:
    def __init__(self, reinforcement_fine_tuning_jobs: ReinforcementFineTuningJobsResource) -> None:
        self._reinforcement_fine_tuning_jobs = reinforcement_fine_tuning_jobs

        self.create = to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.create,
        )
        self.list = to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.list,
        )
        self.delete = to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.delete,
        )
        self.cancel = to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.cancel,
        )
        self.get = to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.get,
        )
        self.resume = to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.resume,
        )


class AsyncReinforcementFineTuningJobsResourceWithRawResponse:
    def __init__(self, reinforcement_fine_tuning_jobs: AsyncReinforcementFineTuningJobsResource) -> None:
        self._reinforcement_fine_tuning_jobs = reinforcement_fine_tuning_jobs

        self.create = async_to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.create,
        )
        self.list = async_to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.list,
        )
        self.delete = async_to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.delete,
        )
        self.cancel = async_to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.cancel,
        )
        self.get = async_to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.get,
        )
        self.resume = async_to_raw_response_wrapper(
            reinforcement_fine_tuning_jobs.resume,
        )


class ReinforcementFineTuningJobsResourceWithStreamingResponse:
    def __init__(self, reinforcement_fine_tuning_jobs: ReinforcementFineTuningJobsResource) -> None:
        self._reinforcement_fine_tuning_jobs = reinforcement_fine_tuning_jobs

        self.create = to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.create,
        )
        self.list = to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.list,
        )
        self.delete = to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.delete,
        )
        self.cancel = to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.cancel,
        )
        self.get = to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.get,
        )
        self.resume = to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.resume,
        )


class AsyncReinforcementFineTuningJobsResourceWithStreamingResponse:
    def __init__(self, reinforcement_fine_tuning_jobs: AsyncReinforcementFineTuningJobsResource) -> None:
        self._reinforcement_fine_tuning_jobs = reinforcement_fine_tuning_jobs

        self.create = async_to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.create,
        )
        self.list = async_to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.delete,
        )
        self.cancel = async_to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.cancel,
        )
        self.get = async_to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.get,
        )
        self.resume = async_to_streamed_response_wrapper(
            reinforcement_fine_tuning_jobs.resume,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["Status"]


class Status(BaseModel):
    code: Optional[
        Literal[
            "OK",
            "CANCELLED",
            "UNKNOWN",
            "INVALID_ARGUMENT",
            "DEADLINE_EXCEEDED",
            "NOT_FOUND",
            "ALREADY_EXISTS",
            "PERMISSION_DENIED",
            "UNAUTHENTICATED",
            "RESOURCE_EXHAUSTED",
            "FAILED_PRECONDITION",
            "ABORTED",
            "OUT_OF_RANGE",
            "UNIMPLEMENTED",
            "INTERNAL",
            "UNAVAILABLE",
            "DATA_LOSS",
        ]
    ] = None
    """The status code."""

    message: Optional[str] = None
    """A developer-facing error message in English."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

from .._types import FileTypes

__all__ = ["DatasetUploadParams"]


class DatasetUploadParams(TypedDict, total=False):
    account_id: str

    file: FileTypes



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from fireworks import Fireworks, AsyncFireworks
from tests.utils import assert_matches_type
from fireworks.types import LoraListResponse
from fireworks.types.shared import DeployedModel

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestLora:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Fireworks) -> None:
        lora = client.lora.update(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Fireworks) -> None:
        lora = client.lora.update(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
            default=True,
            deployment="deployment",
            description="description",
            display_name="displayName",
            model="model",
            public=True,
            serverless=True,
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Fireworks) -> None:
        response = client.lora.with_raw_response.update(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = response.parse()
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Fireworks) -> None:
        with client.lora.with_streaming_response.update(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = response.parse()
            assert_matches_type(DeployedModel, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.lora.with_raw_response.update(
                deployed_model_id="deployed_model_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployed_model_id` but received ''"):
            client.lora.with_raw_response.update(
                deployed_model_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Fireworks) -> None:
        lora = client.lora.list(
            account_id="account_id",
        )
        assert_matches_type(LoraListResponse, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Fireworks) -> None:
        lora = client.lora.list(
            account_id="account_id",
            filter="filter",
            order_by="orderBy",
            page_size=0,
            page_token="pageToken",
            read_mask="readMask",
        )
        assert_matches_type(LoraListResponse, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Fireworks) -> None:
        response = client.lora.with_raw_response.list(
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = response.parse()
        assert_matches_type(LoraListResponse, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Fireworks) -> None:
        with client.lora.with_streaming_response.list(
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = response.parse()
            assert_matches_type(LoraListResponse, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.lora.with_raw_response.list(
                account_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get(self, client: Fireworks) -> None:
        lora = client.lora.get(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_with_all_params(self, client: Fireworks) -> None:
        lora = client.lora.get(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
            read_mask="readMask",
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get(self, client: Fireworks) -> None:
        response = client.lora.with_raw_response.get(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = response.parse()
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get(self, client: Fireworks) -> None:
        with client.lora.with_streaming_response.get(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = response.parse()
            assert_matches_type(DeployedModel, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.lora.with_raw_response.get(
                deployed_model_id="deployed_model_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployed_model_id` but received ''"):
            client.lora.with_raw_response.get(
                deployed_model_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_load(self, client: Fireworks) -> None:
        lora = client.lora.load(
            account_id="account_id",
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_load_with_all_params(self, client: Fireworks) -> None:
        lora = client.lora.load(
            account_id="account_id",
            replace_merged_addon=True,
            default=True,
            deployment="deployment",
            description="description",
            display_name="displayName",
            model="model",
            public=True,
            serverless=True,
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_load(self, client: Fireworks) -> None:
        response = client.lora.with_raw_response.load(
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = response.parse()
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_load(self, client: Fireworks) -> None:
        with client.lora.with_streaming_response.load(
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = response.parse()
            assert_matches_type(DeployedModel, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_load(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.lora.with_raw_response.load(
                account_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_unload(self, client: Fireworks) -> None:
        lora = client.lora.unload(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )
        assert_matches_type(object, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_unload(self, client: Fireworks) -> None:
        response = client.lora.with_raw_response.unload(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = response.parse()
        assert_matches_type(object, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_unload(self, client: Fireworks) -> None:
        with client.lora.with_streaming_response.unload(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = response.parse()
            assert_matches_type(object, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_unload(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.lora.with_raw_response.unload(
                deployed_model_id="deployed_model_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployed_model_id` but received ''"):
            client.lora.with_raw_response.unload(
                deployed_model_id="",
                account_id="account_id",
            )


class TestAsyncLora:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.update(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.update(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
            default=True,
            deployment="deployment",
            description="description",
            display_name="displayName",
            model="model",
            public=True,
            serverless=True,
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncFireworks) -> None:
        response = await async_client.lora.with_raw_response.update(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = await response.parse()
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncFireworks) -> None:
        async with async_client.lora.with_streaming_response.update(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = await response.parse()
            assert_matches_type(DeployedModel, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.lora.with_raw_response.update(
                deployed_model_id="deployed_model_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployed_model_id` but received ''"):
            await async_client.lora.with_raw_response.update(
                deployed_model_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.list(
            account_id="account_id",
        )
        assert_matches_type(LoraListResponse, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.list(
            account_id="account_id",
            filter="filter",
            order_by="orderBy",
            page_size=0,
            page_token="pageToken",
            read_mask="readMask",
        )
        assert_matches_type(LoraListResponse, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncFireworks) -> None:
        response = await async_client.lora.with_raw_response.list(
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = await response.parse()
        assert_matches_type(LoraListResponse, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncFireworks) -> None:
        async with async_client.lora.with_streaming_response.list(
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = await response.parse()
            assert_matches_type(LoraListResponse, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.lora.with_raw_response.list(
                account_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.get(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_with_all_params(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.get(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
            read_mask="readMask",
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get(self, async_client: AsyncFireworks) -> None:
        response = await async_client.lora.with_raw_response.get(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = await response.parse()
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get(self, async_client: AsyncFireworks) -> None:
        async with async_client.lora.with_streaming_response.get(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = await response.parse()
            assert_matches_type(DeployedModel, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.lora.with_raw_response.get(
                deployed_model_id="deployed_model_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployed_model_id` but received ''"):
            await async_client.lora.with_raw_response.get(
                deployed_model_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_load(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.load(
            account_id="account_id",
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_load_with_all_params(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.load(
            account_id="account_id",
            replace_merged_addon=True,
            default=True,
            deployment="deployment",
            description="description",
            display_name="displayName",
            model="model",
            public=True,
            serverless=True,
        )
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_load(self, async_client: AsyncFireworks) -> None:
        response = await async_client.lora.with_raw_response.load(
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = await response.parse()
        assert_matches_type(DeployedModel, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_load(self, async_client: AsyncFireworks) -> None:
        async with async_client.lora.with_streaming_response.load(
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = await response.parse()
            assert_matches_type(DeployedModel, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_load(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.lora.with_raw_response.load(
                account_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_unload(self, async_client: AsyncFireworks) -> None:
        lora = await async_client.lora.unload(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )
        assert_matches_type(object, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_unload(self, async_client: AsyncFireworks) -> None:
        response = await async_client.lora.with_raw_response.unload(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lora = await response.parse()
        assert_matches_type(object, lora, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_unload(self, async_client: AsyncFireworks) -> None:
        async with async_client.lora.with_streaming_response.unload(
            deployed_model_id="deployed_model_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lora = await response.parse()
            assert_matches_type(object, lora, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_unload(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.lora.with_raw_response.unload(
                deployed_model_id="deployed_model_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployed_model_id` but received ''"):
            await async_client.lora.with_raw_response.unload(
                deployed_model_id="",
                account_id="account_id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from fireworks import Fireworks, AsyncFireworks
from tests.utils import assert_matches_type
from fireworks.types import (
    Deployment,
    DeploymentListResponse,
)
from fireworks._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDeployments:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Fireworks) -> None:
        deployment = client.deployments.create(
            account_id="account_id",
            base_model="baseModel",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Fireworks) -> None:
        deployment = client.deployments.create(
            account_id="account_id",
            base_model="baseModel",
            deployment_id="deploymentId",
            disable_auto_deploy=True,
            disable_speculative_decoding=True,
            skip_shape_validation=True,
            validate_only=True,
            accelerator_count=0,
            accelerator_type="ACCELERATOR_TYPE_UNSPECIFIED",
            active_model_version="activeModelVersion",
            autoscaling_policy={
                "load_targets": {"foo": 0},
                "scale_down_window": "scaleDownWindow",
                "scale_to_zero_window": "scaleToZeroWindow",
                "scale_up_window": "scaleUpWindow",
            },
            auto_tune={"long_prompt": True},
            deployment_shape="deploymentShape",
            deployment_template="deploymentTemplate",
            description="description",
            direct_route_api_keys=["string"],
            direct_route_type="DIRECT_ROUTE_TYPE_UNSPECIFIED",
            disable_deployment_size_validation=True,
            display_name="displayName",
            draft_model="draftModel",
            draft_token_count=0,
            enable_addons=True,
            enable_hot_load=True,
            enable_hot_reload_latest_addon=True,
            enable_mtp=True,
            enable_session_affinity=True,
            expire_time=parse_datetime("2019-12-27T18:11:19.117Z"),
            hot_load_bucket_type="BUCKET_TYPE_UNSPECIFIED",
            max_replica_count=0,
            min_replica_count=0,
            ngram_speculation_length=0,
            placement={
                "multi_region": "MULTI_REGION_UNSPECIFIED",
                "region": "REGION_UNSPECIFIED",
                "regions": ["REGION_UNSPECIFIED"],
            },
            precision="PRECISION_UNSPECIFIED",
            target_model_version="targetModelVersion",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Fireworks) -> None:
        response = client.deployments.with_raw_response.create(
            account_id="account_id",
            base_model="baseModel",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = response.parse()
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Fireworks) -> None:
        with client.deployments.with_streaming_response.create(
            account_id="account_id",
            base_model="baseModel",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = response.parse()
            assert_matches_type(Deployment, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_create(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.deployments.with_raw_response.create(
                account_id="",
                base_model="baseModel",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Fireworks) -> None:
        deployment = client.deployments.update(
            deployment_id="deployment_id",
            account_id="account_id",
            base_model="baseModel",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Fireworks) -> None:
        deployment = client.deployments.update(
            deployment_id="deployment_id",
            account_id="account_id",
            base_model="baseModel",
            accelerator_count=0,
            accelerator_type="ACCELERATOR_TYPE_UNSPECIFIED",
            active_model_version="activeModelVersion",
            autoscaling_policy={
                "load_targets": {"foo": 0},
                "scale_down_window": "scaleDownWindow",
                "scale_to_zero_window": "scaleToZeroWindow",
                "scale_up_window": "scaleUpWindow",
            },
            auto_tune={"long_prompt": True},
            deployment_shape="deploymentShape",
            deployment_template="deploymentTemplate",
            description="description",
            direct_route_api_keys=["string"],
            direct_route_type="DIRECT_ROUTE_TYPE_UNSPECIFIED",
            disable_deployment_size_validation=True,
            display_name="displayName",
            draft_model="draftModel",
            draft_token_count=0,
            enable_addons=True,
            enable_hot_load=True,
            enable_hot_reload_latest_addon=True,
            enable_mtp=True,
            enable_session_affinity=True,
            expire_time=parse_datetime("2019-12-27T18:11:19.117Z"),
            hot_load_bucket_type="BUCKET_TYPE_UNSPECIFIED",
            max_replica_count=0,
            min_replica_count=0,
            ngram_speculation_length=0,
            placement={
                "multi_region": "MULTI_REGION_UNSPECIFIED",
                "region": "REGION_UNSPECIFIED",
                "regions": ["REGION_UNSPECIFIED"],
            },
            precision="PRECISION_UNSPECIFIED",
            target_model_version="targetModelVersion",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Fireworks) -> None:
        response = client.deployments.with_raw_response.update(
            deployment_id="deployment_id",
            account_id="account_id",
            base_model="baseModel",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = response.parse()
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Fireworks) -> None:
        with client.deployments.with_streaming_response.update(
            deployment_id="deployment_id",
            account_id="account_id",
            base_model="baseModel",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = response.parse()
            assert_matches_type(Deployment, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.deployments.with_raw_response.update(
                deployment_id="deployment_id",
                account_id="",
                base_model="baseModel",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            client.deployments.with_raw_response.update(
                deployment_id="",
                account_id="account_id",
                base_model="baseModel",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Fireworks) -> None:
        deployment = client.deployments.list(
            account_id="account_id",
        )
        assert_matches_type(DeploymentListResponse, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Fireworks) -> None:
        deployment = client.deployments.list(
            account_id="account_id",
            filter="filter",
            order_by="orderBy",
            page_size=0,
            page_token="pageToken",
            read_mask="readMask",
            show_deleted=True,
        )
        assert_matches_type(DeploymentListResponse, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Fireworks) -> None:
        response = client.deployments.with_raw_response.list(
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = response.parse()
        assert_matches_type(DeploymentListResponse, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Fireworks) -> None:
        with client.deployments.with_streaming_response.list(
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = response.parse()
            assert_matches_type(DeploymentListResponse, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.deployments.with_raw_response.list(
                account_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Fireworks) -> None:
        deployment = client.deployments.delete(
            deployment_id="deployment_id",
            account_id="account_id",
        )
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_with_all_params(self, client: Fireworks) -> None:
        deployment = client.deployments.delete(
            deployment_id="deployment_id",
            account_id="account_id",
            hard=True,
            ignore_checks=True,
        )
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Fireworks) -> None:
        response = client.deployments.with_raw_response.delete(
            deployment_id="deployment_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = response.parse()
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Fireworks) -> None:
        with client.deployments.with_streaming_response.delete(
            deployment_id="deployment_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = response.parse()
            assert_matches_type(object, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.deployments.with_raw_response.delete(
                deployment_id="deployment_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            client.deployments.with_raw_response.delete(
                deployment_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get(self, client: Fireworks) -> None:
        deployment = client.deployments.get(
            deployment_id="deployment_id",
            account_id="account_id",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_with_all_params(self, client: Fireworks) -> None:
        deployment = client.deployments.get(
            deployment_id="deployment_id",
            account_id="account_id",
            read_mask="readMask",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get(self, client: Fireworks) -> None:
        response = client.deployments.with_raw_response.get(
            deployment_id="deployment_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = response.parse()
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get(self, client: Fireworks) -> None:
        with client.deployments.with_streaming_response.get(
            deployment_id="deployment_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = response.parse()
            assert_matches_type(Deployment, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.deployments.with_raw_response.get(
                deployment_id="deployment_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            client.deployments.with_raw_response.get(
                deployment_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_scale(self, client: Fireworks) -> None:
        deployment = client.deployments.scale(
            deployment_id="deployment_id",
            account_id="account_id",
        )
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_scale_with_all_params(self, client: Fireworks) -> None:
        deployment = client.deployments.scale(
            deployment_id="deployment_id",
            account_id="account_id",
            replica_count=0,
        )
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_scale(self, client: Fireworks) -> None:
        response = client.deployments.with_raw_response.scale(
            deployment_id="deployment_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = response.parse()
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_scale(self, client: Fireworks) -> None:
        with client.deployments.with_streaming_response.scale(
            deployment_id="deployment_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = response.parse()
            assert_matches_type(object, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_scale(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.deployments.with_raw_response.scale(
                deployment_id="deployment_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            client.deployments.with_raw_response.scale(
                deployment_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_undelete(self, client: Fireworks) -> None:
        deployment = client.deployments.undelete(
            deployment_id="deployment_id",
            account_id="account_id",
            body={},
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_undelete(self, client: Fireworks) -> None:
        response = client.deployments.with_raw_response.undelete(
            deployment_id="deployment_id",
            account_id="account_id",
            body={},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = response.parse()
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_undelete(self, client: Fireworks) -> None:
        with client.deployments.with_streaming_response.undelete(
            deployment_id="deployment_id",
            account_id="account_id",
            body={},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = response.parse()
            assert_matches_type(Deployment, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_undelete(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.deployments.with_raw_response.undelete(
                deployment_id="deployment_id",
                account_id="",
                body={},
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            client.deployments.with_raw_response.undelete(
                deployment_id="",
                account_id="account_id",
                body={},
            )


class TestAsyncDeployments:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.create(
            account_id="account_id",
            base_model="baseModel",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.create(
            account_id="account_id",
            base_model="baseModel",
            deployment_id="deploymentId",
            disable_auto_deploy=True,
            disable_speculative_decoding=True,
            skip_shape_validation=True,
            validate_only=True,
            accelerator_count=0,
            accelerator_type="ACCELERATOR_TYPE_UNSPECIFIED",
            active_model_version="activeModelVersion",
            autoscaling_policy={
                "load_targets": {"foo": 0},
                "scale_down_window": "scaleDownWindow",
                "scale_to_zero_window": "scaleToZeroWindow",
                "scale_up_window": "scaleUpWindow",
            },
            auto_tune={"long_prompt": True},
            deployment_shape="deploymentShape",
            deployment_template="deploymentTemplate",
            description="description",
            direct_route_api_keys=["string"],
            direct_route_type="DIRECT_ROUTE_TYPE_UNSPECIFIED",
            disable_deployment_size_validation=True,
            display_name="displayName",
            draft_model="draftModel",
            draft_token_count=0,
            enable_addons=True,
            enable_hot_load=True,
            enable_hot_reload_latest_addon=True,
            enable_mtp=True,
            enable_session_affinity=True,
            expire_time=parse_datetime("2019-12-27T18:11:19.117Z"),
            hot_load_bucket_type="BUCKET_TYPE_UNSPECIFIED",
            max_replica_count=0,
            min_replica_count=0,
            ngram_speculation_length=0,
            placement={
                "multi_region": "MULTI_REGION_UNSPECIFIED",
                "region": "REGION_UNSPECIFIED",
                "regions": ["REGION_UNSPECIFIED"],
            },
            precision="PRECISION_UNSPECIFIED",
            target_model_version="targetModelVersion",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncFireworks) -> None:
        response = await async_client.deployments.with_raw_response.create(
            account_id="account_id",
            base_model="baseModel",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = await response.parse()
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncFireworks) -> None:
        async with async_client.deployments.with_streaming_response.create(
            account_id="account_id",
            base_model="baseModel",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = await response.parse()
            assert_matches_type(Deployment, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_create(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.deployments.with_raw_response.create(
                account_id="",
                base_model="baseModel",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.update(
            deployment_id="deployment_id",
            account_id="account_id",
            base_model="baseModel",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.update(
            deployment_id="deployment_id",
            account_id="account_id",
            base_model="baseModel",
            accelerator_count=0,
            accelerator_type="ACCELERATOR_TYPE_UNSPECIFIED",
            active_model_version="activeModelVersion",
            autoscaling_policy={
                "load_targets": {"foo": 0},
                "scale_down_window": "scaleDownWindow",
                "scale_to_zero_window": "scaleToZeroWindow",
                "scale_up_window": "scaleUpWindow",
            },
            auto_tune={"long_prompt": True},
            deployment_shape="deploymentShape",
            deployment_template="deploymentTemplate",
            description="description",
            direct_route_api_keys=["string"],
            direct_route_type="DIRECT_ROUTE_TYPE_UNSPECIFIED",
            disable_deployment_size_validation=True,
            display_name="displayName",
            draft_model="draftModel",
            draft_token_count=0,
            enable_addons=True,
            enable_hot_load=True,
            enable_hot_reload_latest_addon=True,
            enable_mtp=True,
            enable_session_affinity=True,
            expire_time=parse_datetime("2019-12-27T18:11:19.117Z"),
            hot_load_bucket_type="BUCKET_TYPE_UNSPECIFIED",
            max_replica_count=0,
            min_replica_count=0,
            ngram_speculation_length=0,
            placement={
                "multi_region": "MULTI_REGION_UNSPECIFIED",
                "region": "REGION_UNSPECIFIED",
                "regions": ["REGION_UNSPECIFIED"],
            },
            precision="PRECISION_UNSPECIFIED",
            target_model_version="targetModelVersion",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncFireworks) -> None:
        response = await async_client.deployments.with_raw_response.update(
            deployment_id="deployment_id",
            account_id="account_id",
            base_model="baseModel",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = await response.parse()
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncFireworks) -> None:
        async with async_client.deployments.with_streaming_response.update(
            deployment_id="deployment_id",
            account_id="account_id",
            base_model="baseModel",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = await response.parse()
            assert_matches_type(Deployment, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.deployments.with_raw_response.update(
                deployment_id="deployment_id",
                account_id="",
                base_model="baseModel",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            await async_client.deployments.with_raw_response.update(
                deployment_id="",
                account_id="account_id",
                base_model="baseModel",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.list(
            account_id="account_id",
        )
        assert_matches_type(DeploymentListResponse, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.list(
            account_id="account_id",
            filter="filter",
            order_by="orderBy",
            page_size=0,
            page_token="pageToken",
            read_mask="readMask",
            show_deleted=True,
        )
        assert_matches_type(DeploymentListResponse, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncFireworks) -> None:
        response = await async_client.deployments.with_raw_response.list(
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = await response.parse()
        assert_matches_type(DeploymentListResponse, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncFireworks) -> None:
        async with async_client.deployments.with_streaming_response.list(
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = await response.parse()
            assert_matches_type(DeploymentListResponse, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.deployments.with_raw_response.list(
                account_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.delete(
            deployment_id="deployment_id",
            account_id="account_id",
        )
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_with_all_params(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.delete(
            deployment_id="deployment_id",
            account_id="account_id",
            hard=True,
            ignore_checks=True,
        )
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncFireworks) -> None:
        response = await async_client.deployments.with_raw_response.delete(
            deployment_id="deployment_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = await response.parse()
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncFireworks) -> None:
        async with async_client.deployments.with_streaming_response.delete(
            deployment_id="deployment_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = await response.parse()
            assert_matches_type(object, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.deployments.with_raw_response.delete(
                deployment_id="deployment_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            await async_client.deployments.with_raw_response.delete(
                deployment_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.get(
            deployment_id="deployment_id",
            account_id="account_id",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_with_all_params(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.get(
            deployment_id="deployment_id",
            account_id="account_id",
            read_mask="readMask",
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get(self, async_client: AsyncFireworks) -> None:
        response = await async_client.deployments.with_raw_response.get(
            deployment_id="deployment_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = await response.parse()
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get(self, async_client: AsyncFireworks) -> None:
        async with async_client.deployments.with_streaming_response.get(
            deployment_id="deployment_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = await response.parse()
            assert_matches_type(Deployment, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.deployments.with_raw_response.get(
                deployment_id="deployment_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            await async_client.deployments.with_raw_response.get(
                deployment_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_scale(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.scale(
            deployment_id="deployment_id",
            account_id="account_id",
        )
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_scale_with_all_params(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.scale(
            deployment_id="deployment_id",
            account_id="account_id",
            replica_count=0,
        )
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_scale(self, async_client: AsyncFireworks) -> None:
        response = await async_client.deployments.with_raw_response.scale(
            deployment_id="deployment_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = await response.parse()
        assert_matches_type(object, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_scale(self, async_client: AsyncFireworks) -> None:
        async with async_client.deployments.with_streaming_response.scale(
            deployment_id="deployment_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = await response.parse()
            assert_matches_type(object, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_scale(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.deployments.with_raw_response.scale(
                deployment_id="deployment_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            await async_client.deployments.with_raw_response.scale(
                deployment_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_undelete(self, async_client: AsyncFireworks) -> None:
        deployment = await async_client.deployments.undelete(
            deployment_id="deployment_id",
            account_id="account_id",
            body={},
        )
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_undelete(self, async_client: AsyncFireworks) -> None:
        response = await async_client.deployments.with_raw_response.undelete(
            deployment_id="deployment_id",
            account_id="account_id",
            body={},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deployment = await response.parse()
        assert_matches_type(Deployment, deployment, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_undelete(self, async_client: AsyncFireworks) -> None:
        async with async_client.deployments.with_streaming_response.undelete(
            deployment_id="deployment_id",
            account_id="account_id",
            body={},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deployment = await response.parse()
            assert_matches_type(Deployment, deployment, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_undelete(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.deployments.with_raw_response.undelete(
                deployment_id="deployment_id",
                account_id="",
                body={},
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `deployment_id` but received ''"):
            await async_client.deployments.with_raw_response.undelete(
                deployment_id="",
                account_id="account_id",
                body={},
            )
